/*
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 *
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA.
 * 
 * Contact Information:
 * Dambach-Werke GmbH
 * Elektronische Leitsysteme
 * Fritz-Minhardt-Str. 1
 * 76456 Kuppenheim
 * Phone: +49-7222-402-0
 * Fax: +49-7222-402-200
 * mailto: info@els.dambach.de
 */

package de.bsvrz.vew.sim.sim.steuerung;

/**
 * Gemeinsame Funktionalitt von Simulationssteuerungen
 * 
 * @version  $Revision: 1.2 $ / $Date: 2008/10/31 13:30:30 $ / ($Author: Sans $)
 * @author  Dambach-Werke GmbH
 * @author  Stefan Sans
 */
public interface SteuerungSimulation
{
  
  /**
   * In dieser Methode wird der Workflow zu den Zustandsbergngen 
   * implementiert
   * @param uebergang Id fr den Zustandsbergang
   * @return true wenn erfolgreich, false sonst
   */
  public boolean erstelleWorkflow(int uebergang);
  
  /**
   * Sende den aktuellen Zustand der Simulation an den Datenverteiler
   * @return true wenn erfolgreich, false sonst
   */    
  public boolean sendeZustand();
  
  /**
   * Sende "Starten der Applikationen der Simulationsstrecke" an die
   * SWE StartStopp
   * @return true, wenn erfolgreich, false sonst
   */
  public boolean sendeStart();
  
  /**
   * Sende "Stoppen der Applikationen der Simulationsstrecke" an die
   * SWE StartStopp
   * @return true, wenn erfolgreich, false sonst
   */
  public boolean sendeStop();
  
  /**
   * Sende "Beenden/Lschen der Applikationen der Simulationsstrecke" an die
   * SWE StartStopp
   * @return true, wenn erfolgreich, false sonst
   */
  public boolean sendeBeenden();
  
}
